slepc-3.18.0 2022-10-01
Report Typos and Errors

# PEPMonitorAll

Print the current approximate values and error estimates at each iteration of the polynomial eigensolver.

### Synopsis

    #include "slepcpep.h"
    PetscErrorCode PEPMonitorAll(PEP pep,PetscInt its,PetscInt nconv,PetscScalar *eigr,PetscScalar *eigi,PetscReal *errest,PetscInt nest,PetscViewerAndFormat *vf)

Collective on pep

### Input Parameters

| pep | - polynomial eigensolver context
| its | - iteration number
| nconv | - number of converged eigenpairs so far
| eigr | - real part of the eigenvalues
| eigi | - imaginary part of the eigenvalues
| errest | - error estimates
| nest | - number of error estimates to display
| vf | - viewer and format for monitoring

### Options Database Key

| -pep_monitor_all | - activates PEPMonitorAll()

### See Also

PEPMonitorSet(), PEPMonitorFirst(), PEPMonitorConverged()

### Level

intermediate

### Location

src/pep/interface/pepmon.c
Index of all PEP routines
Table of Contents for all manual pages
Index of all manual pages